@@ -5,10 +5,10 @@
 import os
 
 from dealer.git import git
-from google.cloud.logging.handlers import CloudLoggingHandler
-from google.cloud.logging.handlers.transports.background_thread import BackgroundThreadTransport
+from google.cloud.logging_v2.handlers import CloudLoggingHandler
+from google.cloud.logging_v2.handlers.transports.background_thread import BackgroundThreadTransport
 
-from arnoldpaperboy.utils.resource import logging_k8s_container, stringify_label
+from arnoldpaperboy.utils.resource import logging_resource, stringify_label
 
 
 SKIP_LOGRECORD_ATTRS = [
@@ -62,9 +62,9 @@ class StackdriverLoggingHandler(CloudLoggingHandler):
         try:
             tag = str(git.tag)
         except TypeError:
-            tag = os.environ.get('{}_VERSION'.format(app.upper()), '')
+            tag = os.environ.get(f'{app.upper()}_VERSION', '')
 
-        self.resource = logging_k8s_container()
+        self.resource = logging_resource()
 
         if self.labels is None:
             self.labels = {}
@@ -87,7 +87,7 @@ class StackdriverLoggingHandler(CloudLoggingHandler):
 
         record_attrs = {
             k.replace(MAGIC_PREFIX, ''): v for k, v in vars(record).items()
-            if '{}{}'.format(MAGIC_PREFIX, k) not in vars(record)
+            if f'{MAGIC_PREFIX}{k}' not in vars(record)
         }
 
         for key, value in record_attrs.items():
